import { Module } from '@nuxt/types';
import { SanityClient } from '@sanity/client';

interface SanityConfiguration {
    useCdn?: boolean;
    projectId: string;
    dataset?: string;
    withCredentials?: boolean;
    token?: string;
}
declare function createClient(config: SanityConfiguration): {
    clone: () => any;
    /**
     * Perform a fetch using GROQ syntax.
     */
    fetch<T = unknown>(query: string, params?: Record<string, any> | undefined): Promise<T>;
};

declare const groq: (strings: TemplateStringsArray, ...keys: any[]) => string;

interface ModuleOptions extends Partial<SanityConfiguration> {
    /**
     * Use a micro-client that only supports making queries.
     * @default false
     */
    minimal?: boolean;
    /**
     * Register a global SanityImage component to generate correct Sanity image URLs
     * @default true
     */
    imageHelper?: boolean;
}
declare const nuxtModule: Module<ModuleOptions>;
declare module '@nuxt/types' {
    interface NuxtConfig {
        sanity: ModuleOptions;
    }
    interface Configuration {
        sanity: ModuleOptions;
    }
    interface NuxtAppOptions {
        $sanity: {
            client: SanityClient;
            fetch: ReturnType<typeof createClient>['fetch'];
            setToken: (token: string) => void;
        };
    }
}
declare module 'vue/types/vue' {
    interface Vue {
        $sanity: {
            client: SanityClient;
            fetch: ReturnType<typeof createClient>['fetch'];
            setToken: (token: string) => void;
        };
    }
}
declare module 'vuex/types/index' {
    interface Store<S> {
        $sanity: {
            client: SanityClient;
            fetch: ReturnType<typeof createClient>['fetch'];
            setToken: (token: string) => void;
        };
    }
}

export default nuxtModule;
export { ModuleOptions, SanityConfiguration, createClient, groq };
